@@ -1,7 +1,7 @@
 package App::isbn;
 
-our $DATE = '2018-08-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2020-04-10'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -130,7 +130,7 @@ App::isbn - Query book information by ISBN
 
 =head1 VERSION
 
-This document describes version 0.002 of App::isbn (from Perl distribution App-isbn), released on 2018-08-23.
+This document describes version 0.003 of App::isbn (from Perl distribution App-isbn), released on 2020-04-10.
 
 =head1 SYNOPSIS
 
@@ -143,7 +143,7 @@ See L<isbn> script.
 
 Usage:
 
- isbn(%args) -> [status, msg, result, meta]
+ isbn(%args) -> [status, msg, payload, meta]
 
 List available drivers.
 
@@ -172,6 +172,7 @@ and requires L<App::lcpan> and an up-to-date local mini-CPAN.
 
 =item * B<isbn> => I<isbn>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -179,7 +180,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -207,7 +208,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
